/*------------------------------------------------------------------
  |
  |  Program:     BalanX
  |
  |  Description: Measurement and graphic display of the body's
  |               reaction to maintain balance on a one-foot
  |               proprioceptive table, used to help recovery
  |               after a THR (Total Hip Replacement).
  |               Table movement is unidirectional (right/left).
  |               Best performance is to keep the cursor centered
  |               for as long as possible.
  |
  |  Date:        09 December 2020
  |
  -----------------------------------------------------------------*/

#include <Wire.h>
const int MPU = 0x68;          // I2C address of the MPU-6050
int16_t AcX, AcY, AcZ, Tmp, GyX, GyY, GyZ;

void setup() {
  Wire.begin();
  Wire.beginTransmission(MPU);
  Wire.write(0x6B);            // PWR_MGMT_1 register
  Wire.write(0);               // Set to zero (wakes up the MPU-6050)
  Wire.endTransmission(true);
  delay(100);                  // Ensure gyro has enough time to power up
  Serial.begin(115200);
}

void loop() {
  Wire.beginTransmission(MPU);
  Wire.write(0x3B);            // Starting with register 0x3B (ACCEL_XOUT_H)
  Wire.endTransmission(false);
  Wire.requestFrom(MPU, 14, true); // Request a total of 14 registers

  AcX = Wire.read() << 8 | Wire.read(); // 0x3B (ACCEL_XOUT_H) & 0x3C (ACCEL_XOUT_L)
  AcY = Wire.read() << 8 | Wire.read(); // 0x3D (ACCEL_YOUT_H) & 0x3E (ACCEL_YOUT_L)
  AcZ = Wire.read() << 8 | Wire.read(); // 0x3F (ACCEL_ZOUT_H) & 0x40 (ACCEL_ZOUT_L)
  Tmp = Wire.read() << 8 | Wire.read(); // 0x41 (TEMP_OUT_H) & 0x42 (TEMP_OUT_L)
  GyX = Wire.read() << 8 | Wire.read(); // 0x43 (GYRO_XOUT_H) & 0x44 (GYRO_XOUT_L)
  GyY = Wire.read() << 8 | Wire.read(); // 0x45 (GYRO_YOUT_H) & 0x46 (GYRO_YOUT_L)
  GyZ = Wire.read() << 8 | Wire.read(); // 0x47 (GYRO_ZOUT_H) & 0x48 (GYRO_ZOUT_L)

  Serial.print(AcX);           // Print the values to serial port (to Processing)
  Serial.print("/");           // Only the first one is important. The other two
  Serial.print(AcY);           // could be used for future project expansion
  Serial.print("/");
  Serial.println(AcZ);

  delay(10);                   // Wait and scan again

}
